@@ -378,7 +378,7 @@ class WMTSSource(Source):
 
 class CSVSource(Source):
     SEPARATORS = {
-        "coma": ",",
+        "comma": ",",
         "semicolon": ";",
         "tabulation": "\t",
         "space": " ",
@@ -391,26 +391,33 @@ class CSVSource(Source):
 
     def get_file_as_sheet(self):
         separator = self._get_separator(self.settings["field_separator"])
-        with self.file.open(mode="r") as f:
-            try:
-                return pyexcel.get_sheet(
-                    file_type="csv", file_content=f, delimiter=separator
-                )
-            except pyexcel.exceptions.FileTypeNotSupported as err:
-                msg = "Source's CSV file is not valid"
-                logger.info(msg)
-                err.message = msg  # new message for the user
-                raise
+        quotechar = self._get_separator(self.settings["char_delimiter"])
+        try:
+            return pyexcel.get_sheet(
+                file_name=self.file.path,
+                delimiter=separator,
+                encoding=self.settings["encoding"],
+                quotechar=quotechar,
+            )
+        except pyexcel.exceptions.FileTypeNotSupported as err:
+            msg = "Source's CSV file is not valid"
+            logger.info(msg)
+            err.message = msg  # new message for the user
+            raise
 
     def _get_records(self, limit=None):
         sheet = self.get_file_as_sheet()
         if self.settings.get("use_header"):
             sheet.name_columns_by_row(0)
 
+        ignored_columns = []
+        if self.settings.get("ignore_columns"):
+            ignored_columns = self._get_null_columns_indexes(sheet)
+
         limit = limit if limit else len(sheet)
 
         records = []
-        srid = self.settings["coordinate_reference_system"]
+        srid = self._get_srid()
         for row in sheet:
             if self.settings["coordinates_field"] == "two_columns":
                 lat_field = self.settings["latitude_field"]
@@ -419,15 +426,16 @@ class CSVSource(Source):
                 x, y = self._extract_coordinates(
                     row, sheet.colnames, [lng_field, lat_field]
                 )
-                ignored_field = (row.index(x), row.index(y))
+                ignored_field = (row.index(x), row.index(y), *ignored_columns)
             else:
                 lnglat_field = self.settings["latlong_field"]
                 x, y = self._extract_coordinates(row, sheet.colnames, [lnglat_field])
-                ignored_field = (
+                coord_fields = (
                     (sheet.colnames.index(lnglat_field),)
                     if self.settings.get("use_header")
                     else (int(lnglat_field),)
                 )
+                ignored_field = (*coord_fields, *ignored_columns)
 
             records.append(
                 {
@@ -460,11 +468,27 @@ class CSVSource(Source):
             # some fools use a reversed cartesian coordinates system (╯°□°)╯︵ ┻━┻
             x, y = coords[0].split(sep) if is_xy else coords[0].split(sep).reverse()
 
+        # correct formated decimal is required for GEOSGeometry
+        if not self.settings["decimal_separator"] == "point":
+            delimiter = self._get_separator(self.settings["decimal_separator"])
+            x = x.replace(delimiter, ".")
+            y = y.replace(delimiter, ".")
+
         return (x, y)
 
+    def _get_null_columns_indexes(self, sheet):
+        null_columns_indexes = []
+        for i, column in enumerate(sheet.column):
+            non_empty_cells = [cell for cell in column if cell != ""]
+            (len(non_empty_cells) == 0) and null_columns_indexes.append(i)
+        return null_columns_indexes
+
     def _get_separator(self, name):
         return self.SEPARATORS[name]
 
+    def _get_srid(self):
+        return int(self.settings["coordinate_reference_system"].split("_")[1])
+
     # properties are use by serializer for representation (reading operation)
     @property
     def coordinate_reference_system(self):
@@ -476,7 +500,7 @@ class CSVSource(Source):
 
     @property
     def field_separator(self):
-        return self.settings.get("separator")
+        return self.settings.get("field_separator")
 
     @property
     def decimal_separator(self):
@@ -498,6 +522,10 @@ class CSVSource(Source):
     def use_header(self):
         return self.settings.get("use_header")
 
+    @property
+    def ignore_columns(self):
+        return self.settings.get("ignore_columns")
+
     @property
     def latitude_field(self):
         return self.settings.get("latitude_field")
